==> bgpview-alpha0.32.tar.gz: bgpview-alpha0.32/mpnlri.h <==
/****************************************************************/
/* BGP-4 Protocol Viewer                                        */
/*    Programmed By K.Kondo IIJ 2002/03                         */
/*                                                              */
/* Multi Protocol Extentions                                    */
/****************************************************************/
/* mpnlri.h,v 1.3 2002/03/28 09:54:37 kuniaki Exp */

/*
 * Copyright (c) 2002 Internet Initiative Japan Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistribution with functional modification must include
 *    prominent notice stating how and when and by whom it is
 *    modified.
 * 3. Redistributions in binary form have to be along with the source
 *    code or documentation which include above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 4. All commercial advertising materials mentioning features or use
 *    of this software must display the following acknowledgement:
 *      This product includes software developed by Internet
 *      Initiative Japan Inc.
 *
 * THIS SOFTWARE IS PROVIDED BY ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.
 */

#ifndef _MPNLRI_H
#define _MPNLRI_H

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "utils.h"
#include "bgp.h"
#include "bgplog.h"
#include "bgpdata.h"

extern int pr_mp_reach_nlri(/* char *ptr, int len */);
extern int pr_mp_unreach_nlri(/* char *ptr, int len */);

#endif /* _MPNLRI_H */

==> bgpview-alpha0.34.tar.gz: bgpview-alpha0.34/mpnlri.h <==
/****************************************************************/
/* BGP-4 Protocol Viewer                                        */
/*    Programmed By K.Kondo IIJ 2002/03                         */
/*                                                              */
/* Multi Protocol Extentions                                    */
/****************************************************************/
/* mpnlri.h,v 1.4 2002/04/09 09:43:05 kuniaki Exp */

/*
 * Copyright (c) 2002 Internet Initiative Japan Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistribution with functional modification must include
 *    prominent notice stating how and when and by whom it is
 *    modified.
 * 3. Redistributions in binary form have to be along with the source
 *    code or documentation which include above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 4. All commercial advertising materials mentioning features or use
 *    of this software must display the following acknowledgement:
 *      This product includes software developed by Internet
 *      Initiative Japan Inc.
 *
 * THIS SOFTWARE IS PROVIDED BY ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.
 */

#ifndef _MPNLRI_H
#define _MPNLRI_H

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "utils.h"
#include "bgp.h"
#include "bgplog.h"
#include "bgpdata.h"

extern int pr_mp_reach_nlri();
extern int pr_mp_unreach_nlri();
extern void free_v6routebuf(/* V6ROUTE_BUF *rbuf */);

#endif /* _MPNLRI_H */
